# Table of Contents

- [application-of-pace-layering-in-assessments](<./application-of-pace-layering-in-assessments.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Application of Pace Layering in Assessments](<./Application-of-Pace-Layering-in-Assessments.md>)
  - [Overview](<./Application-of-Pace-Layering-in-Assessments/Overview.md>)
  - [Focusing on Specific Capabilities](<./Application-of-Pace-Layering-in-Assessments/Focusing-on-Specific-Capabilities.md>)
  - [Integrating TIME Classification with Pace Layering](<./Application-of-Pace-Layering-in-Assessments/Integrating-TIME-Classification-with-Pace-Layering.md>)
  - [Creating and Implementing a Future-State/To-Be-State Plan](<./Application-of-Pace-Layering-in-Assessments/Creating-and-Implementing-a-Future-StateTo-Be-State-Plan.md>)
